---
name: Feature Request
about: Suggest an idea for this project
title: ''
labels: ["feature", "needs triage"]
assignees: ''

---

## Describe the feature you'd like to see

*Please give a clear and concise description and provide context why the feature would be useful.*
*Also, we'd appreciate any implementation ideas and references you already have.*
